@@ -149,29 +149,31 @@ __DATA__
 <div id="editor"><%= stash('raw') || '---' %></div>
 <div id="resizer">&nbsp;</div>
 <div id="preview"><%= podify $swagger->pod %></div>
-%= javascript "ace.js"
+% my $ace_url = $c->req->url->base->path->clone;
+% push @{$ace_url->parts}, 'ace.js';
+<script src="<%= $ace_url %>"></script>
 %= javascript begin
 (function(ace) {
   var localStorage = window.localStorage || {};
   var draggable = document.getElementById("resizer");
   var editor = document.getElementById("editor");
   var preview = document.getElementById("preview");
+  var focusId = location.href.split("#")[1] || "";
   var initializing = true;
   var tid, xhr, i;
 
-  if (location.href.indexOf("#") < 0) {
-    location.href = location.href + "#toc";
-  }
-
   var loaded = function() {
-    var id = location.href.split("#")[1];
-    var scrollTo = id ? document.getElementById(id) : false;
+    if (initializing) {
+      ace.focus();
+      ace.gotoLine(2);
+    }
     initializing = false;
     ace.session.setMode("ace/mode/" + (ace.getValue().match(/^\s*\{/) ? "json" : "yaml"));
-    if (scrollTo) preview.scrollTop = scrollTo.offsetTop;
+    preview.scrollTop = scrollSave();
   };
 
   var render = function() {
+    scrollSave();
     xhr = new XMLHttpRequest();
     xhr.open("POST", "<%= url_for("/") %>", true);
     xhr.onload = function() { preview.firstChild.innerHTML = xhr.responseText; loaded(); };
@@ -179,6 +181,20 @@ __DATA__
     xhr.send(localStorage["swagger-spec"]);
   };
 
+  var scrollSave = function() {
+    var elem = document.getElementById(location.href.split("#")[1] || "toc");
+    if (!elem) return 0;
+    var last = scrollSave.last;
+    scrollSave.last = preview.scrollTop || elem.offsetTop;
+    return last || scrollSave.last;
+  };
+
+  ace.commands.addCommand({ bindKey: { win: "Ctrl-L", mac: "Command-L" }, command: "passKeysToBrowser" });
+  ace.commands.addCommand({
+    name: "find",
+    bindKey: { win: "Ctrl-F", mac: "Command-F" },
+    exec: function(editor) { editor.find(prompt("Find:", editor.getCopyText())); }
+  });
   ace.setTheme("ace/theme/solarized_dark");
   ace.getSession().on("change", function(e) {
     if (initializing) return;
@@ -186,7 +202,22 @@ __DATA__
     tid = setTimeout(render, 600);
   });
 
-  if (localStorage["swagger-spec"]) {
+  if (!focusId) {
+    location.href = location.href + "#toc";
+  }
+
+  if (focusId.indexOf("/") == 0) {
+    xhr = new XMLHttpRequest();
+    xhr.open("GET", focusId, true);
+    xhr.onload = function() {
+      if (!xhr.responseText.match(/^\s*(---|{)/)) return alert("Could not load specification from " + focusId);
+      ace.setValue(xhr.responseText);
+      render();
+    };
+    xhr.send(false);
+    location.href = location.href.replace(/\#.*/, "#toc");
+  }
+  else if (localStorage["swagger-spec"]) {
     ace.setValue(localStorage["swagger-spec"]);
     render();
   }
